@@ -1,7 +1,7 @@
 from pick import pick
 
 from ftrack_ams.fileserver import create_project_on_fileserver, get_latest_proj
-from ftrack_ams.functions import clearConsole
+from ftrack_ams.functions import clearConsole, select_artist
 from ftrack_ams.functions import create_project_name
 
 
@@ -23,6 +23,10 @@ def create_new_project(session):
     for c in internal_project_handle["children"]:
         if c["name"] == "Assets":
             for a in c["children"]:
+                if a["name"] == "VFB-LOGO":
+                    vfb_thumb = a["thumbnail_id"]
+                if a["name"] == "AMSVFB-LOGO":
+                    amsvfb_thumb = a["thumbnail_id"]
                 if a["name"] == "AMS-LOGO":
                     ams_thumb = a["thumbnail_id"]
 
@@ -44,6 +48,8 @@ def create_new_project(session):
     for m in team["managers"]:
         if "Annelies" not in m["user"]["username"]:
             mgmt.append(m["user"])
+        else:
+            annelies = m["user"]
 
     project_team = []
 
@@ -53,6 +59,20 @@ def create_new_project(session):
             user = resource
             project_team.append(user)
 
+    internal_project = True if "Intern" in team["name"] else False
+
+    if internal_project:
+        departement_choice, departement_index = pick(["AMS", "VFB"],
+                                                     "Select internal department:")
+
+    project_thumb = amsvfb_thumb
+
+    if internal_project and departement_choice == "AMS":
+        project_thumb = ams_thumb
+
+    if internal_project and departement_choice == "VFB":
+        project_thumb = vfb_thumb
+
     dest_folder = None
     for child in team["children"]:
         if child["name"] == "Projects":
@@ -109,26 +129,32 @@ def create_new_project(session):
     else:
         desc = f"{num_int} INT/{num_ext} EXT"
 
-    proj = session.create(
-        "Amsproj",
-        {
-            "name": project_name,
-            "parent": dest_folder,
-            "description": desc,
-            "thumbnail_id": ams_thumb
-        },
-    )
+    if internal_project and departement_choice == "VFB":
+        proj = session.create("Vfbproj", {
+                              "name": project_name,
+                              "parent": dest_folder,
+                              "description": desc,
+                              "thumbnail_id": project_thumb}
+                              )
+    else:
+        proj = session.create("Amsproj", {
+                              "name": project_name,
+                              "parent": dest_folder,
+                              "description": desc,
+                              "thumbnail_id": project_thumb}
+                              )
 
     task_templates = team["project_schema"]["task_templates"]
 
     for template in task_templates:
-        #print(template["name"])
         if template["name"] == "Annelies_Template":
             annelies_template = template
         if template["name"] == "Image_Template":
             image_template = template
         if template["name"] == "PM_Template":
             production_template = template
+        if template["name"] == "Timetracking_Template":
+            timetrack_template = template
 
     pm_choice, index = pick([m["username"] for m in mgmt], "Select project manager")
     project_manager = mgmt[index]
@@ -137,7 +163,7 @@ def create_new_project(session):
         task = session.create("Task",
                               {"name": task_type["name"],
                                "type": task_type,
-                               "thumbnail_id": ams_thumb,
+                               "thumbnail_id": project_thumb,
                                "parent": proj})
         session.create("Appointment", {
                        "context": task,
@@ -145,68 +171,62 @@ def create_new_project(session):
                        "type": "assignment"},
                        )
 
-    for u in users:
-        if u["username"] == "Annelies.Cardoen":
-            annelies = u
-
     for task_type in [t["task_type"] for t in annelies_template["items"]]:
         task = session.create("Task", {
                               "name": task_type["name"],
                               "type": task_type,
-                              "thumbnail_id": ams_thumb,
+                              "thumbnail_id": project_thumb,
                               "parent": proj}
                               )
-        session.create(
-            "Appointment", {"context": task, "resource": annelies, "type": "assignment"}
-        )
+
+        session.create("Appointment", {
+                       "context": task,
+                       "resource": annelies,
+                       "type": "assignment"}
+                       )
 
     if num_int > 0:
         int_folder = session.create("Folder", {
                                     "name": f"{num}_INT",
                                     "parent": proj,
-                                    "thumbnail_id": ams_thumb})
+                                    "thumbnail_id": project_thumb})
 
         if len(project_team) > 1:
-            ia, index = pick(
-                [u["username"] for u in project_team],
-                "Select interior artist:",
-            )
-            int_artist = [i for i in users if ia.lower() in i["username"].lower()][0]
+            int_artist = select_artist(project_team, users, "Select INT artist: ")
         else:
             int_artist = project_team[0]
 
         for i in range(num_int):
             int_shot_name = f"{num}_INT_{chr(ord('@')+i+1)}"
+
             int_shot = session.create("Image", {
                                       "name": int_shot_name,
                                       "parent": int_folder,
-                                      "thumbnail_id": ams_thumb}
+                                      "thumbnail_id": project_thumb}
                                       )
+
             for task_type in [t["task_type"] for t in image_template["items"]]:
                 task = session.create("Task", {
                                       "name": task_type["name"],
                                       "type": task_type,
                                       "parent": int_shot,
-                                      "thumbnail_id": ams_thumb},
+                                      "thumbnail_id": project_thumb},
                                       )
-                session.create(
-                    "Appointment",
-                    {"context": task, "resource": int_artist, "type": "assignment"},
-                )
+                session.create("Appointment", {
+                               "context": task,
+                               "resource": int_artist,
+                               "type": "assignment"},
+                               )
 
     if num_ext > 0:
         ext_folder = session.create("Folder", {
                                     "name": f"{num}_EXT",
                                     "parent": proj,
-                                    "thumbnail_id": ams_thumb}
+                                    "thumbnail_id": project_thumb}
                                     )
 
         if len(project_team) > 1:
-
-            exterior_artist, index = pick([u["username"] for u in project_team], "Select exterior artist:")
-            ext_artist = [
-                i for i in users if exterior_artist.lower() in i["username"].lower()
-            ][0]
+            ext_artist = select_artist(project_team, users, "Select EXT artist: ")
         else:
             ext_artist = project_team[0]
 
@@ -215,28 +235,38 @@ def create_new_project(session):
             ext_shot = session.create("Image", {
                                       "name": ext_shot_name,
                                       "parent": ext_folder,
-                                      "thumbnail_id": ams_thumb}
+                                      "thumbnail_id": project_thumb}
                                       )
             for task_type in [t["task_type"] for t in image_template["items"]]:
                 task = session.create("Task", {
                                       "name": task_type["name"],
                                       "type": task_type,
                                       "parent": ext_shot,
-                                      "thumbnail_id": ams_thumb},
+                                      "thumbnail_id": project_thumb},
                                       )
                 session.create(
                     "Appointment",
                     {"context": task, "resource": ext_artist, "type": "assignment"},
                 )
 
-    # using a set here to make sure non users are added multiple times
+    # using a set here to make sure users aren't added multiple times
     project_set = set()
     project_set.add(int_artist)
     project_set.add(ext_artist)
 
-    for artist in project_set:
-        print(artist["username"])
-        pass
+    if internal_project:
+        for artist in project_set:
+            for task_type in [t["task_type"] for t in timetrack_template["items"]]:
+                task = session.create("Task", {
+                                      "name": f"TT_{artist['first_name']}",
+                                      "type": task_type,
+                                      "thumbnail_id": project_thumb,
+                                      "parent": proj})
+                session.create("Appointment", {
+                               "context": task,
+                               "resource": project_manager,
+                               "type": "assignment"},
+                               )
 
     drone = get_yes_no("Does the project require photography?")
 
